
#ifndef _TW_PTY_H
#define _TW_PTY_H

int Spawn(twindow Window, pid_t *pid, dat X, dat Y, TW_CONST byte *arg0, byte * TW_CONST *argv);

#endif /* _TW_PTY_H */
